cordova.define("cordova-plugin-gprinter.Gprinter", function(require, exports, module) {
var cordova = require('cordova');
var exec = require('cordova/exec');

var Gprinter = {};

Gprinter.resultCodeObj = {
    SUCCESS:0,                  //成功
    NOT_OPENT:1,                //蓝牙未打开
    OPEN_BT_FAILED:2,           //打开蓝牙失败
    NOT_SUPPORT:3,              //设备不支持蓝牙
    TIMEOUT:4,                  //超时
    CONN_BREAK:5,               //连接断开
    START_SERVICE_FAILED:6,     //启动服务失败
    PARAMETER_ERROR:7,          //参数错误
    CONNECTED:8,                //已连接
    UNKNOW_ERROR:9,             //未知错误
    LISTENING:10,               //正在监听
    CONNECTING:11,              //正在连接
    INVALID_PRINTER:12,         //无效打印机
    PRINTER_ERROR:13,            //打印机错误
    NOT_CONN:14,                //未连接
    NO_PERMISSION:15,           //没有权限
    NO_INIT:16                  //没有初始化    
};
Gprinter.eventStatusCode = {};
Gprinter.eventStatusCode.btStatusEvent = {
    BT_BOND_BONDING:1,        //正在配对
    BT_BOND_BONDED:2,        //配对完成
    BT_BOND_NONE:3,         //取消配对/未配对

    BT_STATE_ON:10,         //打开蓝牙
    BT_STATE_OFF:11         //关闭蓝牙
};
Gprinter.eventStatusCode.connectionEvent = {
    CONN_BREAK:4,             //打印机连接断开
    CONN_LISTEN:5,            //监听状态
    CONN_CONNECTING:6,       //正在连接
    CONN_CONNECTED:7,         //已连接/连接成功
    CONN_INVALID_PRINTER:8,   //无效打印机
    CONN_VALID_PRINTER:9     //有效打印机
};


function GprinterEvent(){
    this.channels = {
        btStatusEvent:cordova.addWindowEventHandler("btstatusevent"),
        printerStatusEvent:cordova.addWindowEventHandler("printerstatusevent"),
        connectionEvent:cordova.addWindowEventHandler("connectionevent"),
        btFindEvent:cordova.addWindowEventHandler("btfindevent"),
        btFindFinishedEvent:cordova.addWindowEventHandler("btfindfinishedevent"),
        printFinishedEvent:cordova.addWindowEventHandler("printfinishedevent")
    };
    for(var key in this.channels){
        this.channels[key].onHasSubscribersChange = GprinterEvent.onHasSubscribersChange;
    }
};
function handlers(){
    return gprinterEvent.channels.btStatusEvent.numHandlers +
        gprinterEvent.channels.printerStatusEvent.numHandlers +
        gprinterEvent.channels.btFindEvent.numHandlers +
        gprinterEvent.channels.btFindFinishedEvent.numHandlers +
        gprinterEvent.channels.connectionEvent.numHandlers +
        gprinterEvent.channels.printFinishedEvent.numHandlers;
}
GprinterEvent.onHasSubscribersChange = function(){
    if (this.numHandlers === 1 && handlers() === 1) {
        exec(gprinterEvent._status,gprinterEvent._error, 'Gprinter', 'startEvent', []);
    } else if (handlers() === 0) {
        exec(null, null, 'Gprinter', 'stopEvent', []);
    }
};
GprinterEvent.prototype._status = function(info){
    if(info){
        cordova.fireWindowEvent(info.eventName, {data:info});
    }else{
        return;
    }
};
GprinterEvent.prototype._error = function(e){
    console.log('Error initializing GprinterEvent: ' + e)
}


var gprinterEvent = new GprinterEvent();
Gprinter.gprinterEvent = gprinterEvent;

var successFun = function(resolve){
    return function(result){
        resolve(result);
    };
};
var failedFun = function(reject){
    return function(result){
        reject(result);
    };
};

Gprinter.btIsEnabled = function(){
    return new Promise(function(resolve,reject){
        exec(successFun(resolve),failedFun(reject), 'Gprinter',"btIsEnabled", []);
    });
};
Gprinter.openBt = function(){
    return new Promise(function(resolve,reject){
        exec(successFun(resolve),failedFun(reject), 'Gprinter',"openBt", []);
    });
};
Gprinter.discoveryBt = function(){
    return new Promise(function(resolve,reject){
        exec(successFun(resolve),failedFun(reject), 'Gprinter',"discoveryBt", []);
    });
};


Gprinter.cancelDiscoveryBt = function(){
    return new Promise(function(resolve,reject){
        exec(successFun(resolve),failedFun(reject), 'Gprinter',"cancelDiscoveryBt", []);
    });
};

Gprinter.getMatchBtList = function(){
    return new Promise(function(resolve,reject){
        exec(successFun(resolve),failedFun(reject),"Gprinter","getMatchBtList",[]);
    });
};

Gprinter.initPrinterService = function(){
    return new Promise(function(resolve,reject){
        exec(successFun(resolve),failedFun(reject),"Gprinter","initPrinterService",[]);
    });
};
Gprinter.connectPrinterDev = function(btAddress){
    return new Promise(function(resolve,reject){
        exec(successFun(resolve),failedFun(reject),"Gprinter","connectPrinterDev",[btAddress]);
    });
};
//--------------新加改版接口--------------------------------
Gprinter.connectPrinterDevNew = function(btAddress){
    return new Promise(function(resolve,reject){
        exec(successFun(resolve),failedFun(reject),"Gprinter","connectPrinterDevNew",[btAddress]);
    });
};
Gprinter.queryPrinterStatus = function(timeout){
    timeout = timeout || 1000;
    return new Promise(function(resolve,reject){
        exec(successFun(resolve),failedFun(reject),"Gprinter","queryPrinterStatus",[timeout]);
    });
};
//--------------------------新加改版接口-------------------------
Gprinter.queryPrinterStatusNew = function(timeout){
    timeout = timeout || 1000;
    return new Promise(function(resolve,reject){
        exec(successFun(resolve),failedFun(reject),"Gprinter","queryPrinterStatusNew",[timeout]);
    });
};
Gprinter.printTestPage = function(){
    return new Promise(function(resolve,reject){
        exec(successFun(resolve),failedFun(reject),"Gprinter","printTestPage",[]);
    });
};

Gprinter.printText = function(printerLineList){
    return new Promise(function(resolve,reject){
        if(printerLineList instanceof Array && printerLineList.length > 0){
            exec(successFun(resolve),failedFun(reject),"Gprinter","printText",printerLineList);
        }else{
            reject(this.resultCodeObj.PARAMETER_ERROR);
        }
    });
};
//--------------------------新加改版接口-------------------------
Gprinter.printTextNew = function(printerLineList){
    return new Promise(function(resolve,reject){
        if(printerLineList instanceof Array && printerLineList.length > 0){
            exec(successFun(resolve),failedFun(reject),"Gprinter","printTextNew",printerLineList);
        }else{
            reject(this.resultCodeObj.PARAMETER_ERROR);
        }
    });
};
Gprinter.disConnection = function(){
    return new Promise(function(resolve,reject){
        exec(successFun(resolve),failedFun(reject),"Gprinter","disConnection",[]);
    });
};
//--------------------------新加改版接口-------------------------
Gprinter.disConnectionNew = function(){
    return new Promise(function(resolve,reject){
        exec(successFun(resolve),failedFun(reject),"Gprinter","disConnectionNew",[]);
    });
};
Gprinter.closePrinterService = function(){
    return new Promise(function(resolve,reject){
        exec(successFun(resolve),failedFun(reject),"Gprinter","closePrinterService",[]);
    });
};
Gprinter.bondBtDev = function(btAddress){
    return new Promise(function(resolve,reject){
        exec(successFun(resolve),failedFun(reject),"Gprinter","bondBtDev",[btAddress]);
    });
};
Gprinter.queryConectionStatus = function(){
    return new Promise(function(resolve,reject){
        exec(successFun(resolve),failedFun(reject),"Gprinter","queryConectionStatus",[]);
    });
};



module.exports = Gprinter;

});
